@@ -3,7 +3,7 @@ from haystack import indexes
 from docviewer.models import Page
 
 
-class PageIndex(indexes.RealTimeSearchIndex, indexes.Indexable):
+class PageIndex(indexes.SearchIndex, indexes.Indexable):
 
     text = indexes.CharField(document=True)
     document_id =  indexes.IntegerField(model_attr='document__id')
@@ -15,5 +15,3 @@ class PageIndex(indexes.RealTimeSearchIndex, indexes.Indexable):
     def get_model(self):
         return Page
             
-    def index_queryset(self):
-        return self.get_model().objects.all()
